==> freecad_0.10.3247.dfsg.orig.tar.gz: FreeCAD-0.10.3247/src/Base/UnitsSchemaInternal.h <==
/***************************************************************************
 *   Copyright (c) 2009 Juergen Riegel  (FreeCAD@juergen-riegel.net>              *
 *                                                                         *
 *   This file is part of the FreeCAD CAx development system.              *
 *                                                                         *
 *   This library is free software; you can redistribute it and/or         *
 *   modify it under the terms of the GNU Library General Public           *
 *   License as published by the Free Software Foundation; either          *
 *   version 2 of the License, or (at your option) any later version.      *
 *                                                                         *
 *   This library  is distributed in the hope that it will be useful,      *
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
 *   GNU Library General Public License for more details.                  *
 *                                                                         *
 *   You should have received a copy of the GNU Library General Public     *
 *   License along with this library; see the file COPYING.LIB. If not,    *
 *   write to the Free Software Foundation, Inc., 59 Temple Place,         *
 *   Suite 330, Boston, MA  02111-1307, USA                                *
 *                                                                         *
 ***************************************************************************/


#ifndef BASE_UNITSSCHEMAINTERNAL_H
#define BASE_UNITSSCHEMAINTERNAL_H


#include <string>
#include <QString>
#include "UnitsSchema.h"

namespace Base {
    

/**
 * The UnitSchema class
 */
class UnitsSchemaInternal: public UnitsSchema
{
public:
    void setSchemaUnits(void);
    void toStrWithUserPrefs(QuantityType t,double Value,QString &outValue,QString &outUnit);
};


} // namespace Base


#endif // BASE_UNITSSCHEMAINTERNAL_H

==> freecad_0.12.5284-dfsg.orig.tar.gz: FreeCAD-0.12.5284/src/Base/UnitsSchemaInternal.h <==
/***************************************************************************
 *   Copyright (c) 2009 Juergen Riegel  (FreeCAD@juergen-riegel.net>              *
 *                                                                         *
 *   This file is part of the FreeCAD CAx development system.              *
 *                                                                         *
 *   This library is free software; you can redistribute it and/or         *
 *   modify it under the terms of the GNU Library General Public           *
 *   License as published by the Free Software Foundation; either          *
 *   version 2 of the License, or (at your option) any later version.      *
 *                                                                         *
 *   This library  is distributed in the hope that it will be useful,      *
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
 *   GNU Library General Public License for more details.                  *
 *                                                                         *
 *   You should have received a copy of the GNU Library General Public     *
 *   License along with this library; see the file COPYING.LIB. If not,    *
 *   write to the Free Software Foundation, Inc., 59 Temple Place,         *
 *   Suite 330, Boston, MA  02111-1307, USA                                *
 *                                                                         *
 ***************************************************************************/


#ifndef BASE_UNITSSCHEMAINTERNAL_H
#define BASE_UNITSSCHEMAINTERNAL_H


#include <string>
#include <QString>
#include "UnitsSchema.h"

namespace Base {
    

/** The standard units schema
 *  Here is defined what internal (base) units FreeCAD uses.
 *  FreeCAD uses a mm/kg/deg scala.
 *  Also it defines how the units get presented.
 */
class UnitsSchemaInternal: public UnitsSchema
{
public:
    void setSchemaUnits(void);
    void toStrWithUserPrefs(QuantityType t,double Value,QString &outValue,QString &outUnit);
    QString toStrWithUserPrefs(QuantityType t,double Value);
};


} // namespace Base


#endif // BASE_UNITSSCHEMAINTERNAL_H
